{-************************ Mdulo que implementa as funes auxiliares e comuns a alguns scripts  ************************-}
{-***********************************- Autoria: Monique Louise de Barros Monteiro ****************************************-}


module Util where

import System

type Day = Int
type Month = Int
type Year = Int  
type Hour = Int
type Minute = Int
type Second = Int
data Date = Date Day Month Year Hour Minute Second
            deriving (Show, Eq, Ord)
            
{-************************************ Funes de data e hora ***************************************************-}
            
-- Retorna a data de hoje            
dataDeHoje :: IO Date
dataDeHoje = system "date > date.txt" >>                  
             readFile "date.txt" 
             >>= 
             \str -> if str == "" then error "arquivo vazio!" else
             return (converteData (separaEmPalavras str) (indiceMes))            
				
-- Converte uma lista de strings em uma data, recebendo uma funo de converso de mes						
converteData :: [String] -> (String -> Int) -> Date
converteData lista conversorIndiceMes = (Date ((read (lista !! 2)) :: Int) 
                             (conversorIndiceMes (lista !! 1))
                             ((read (lista !! 7)) :: Int)                           
                             ((read (lista !! 3)) :: Int)                           
                             ((read (lista !! 4)) :: Int) 
                             ((read (lista !! 5)) :: Int)                                                     
                    )
                                    
-- Retorna verdadeiro se a primeira data  anterior  segunda
anterior :: Date -> Date -> Bool
anterior (Date dia1 mes1 ano1 hora1 min1 seg1) (Date dia2 mes2 ano2 hora2 min2 seg2)
	| ano1 < ano2 = True
	| (ano1 == ano2) && (mes1 < mes2) = True
	| (ano1 == ano2) && (mes1 == mes2) && (dia1 < dia2) = True	
	| (ano1 == ano2) && (mes1 == mes2) && (dia1 == dia2) && (hora1 < hora2) = True	
	| otherwise = False


indiceMes :: String -> Int
indiceMes "Jan" = 1		                                   	   
indiceMes "Feb" = 2
indiceMes "Mar" = 3
indiceMes "Apr" = 4 
indiceMes "May" = 5
indiceMes "Jun" = 6
indiceMes "Jul" = 7
indiceMes "Aug" = 8
indiceMes "Sep" = 9
indiceMes "Oct" = 10
indiceMes "Nov" = 11
indiceMes "Dec" = 12

indiceMes2 :: String -> Int
indiceMes2 "jan" = 1		                                   	   
indiceMes2 "feb" = 2
indiceMes2 "mar" = 3
indiceMes2 "abr" = 4 
indiceMes2 "mai" = 5
indiceMes2 "jun" = 6
indiceMes2 "jul" = 7
indiceMes2 "ago" = 8
indiceMes2 "set" = 9
indiceMes2 "out" = 10
indiceMes2 "nov" = 11
indiceMes2 "dez" = 12

mesIndice :: Int -> String
mesIndice 1 = "jan"
mesIndice 2 = "fev"
mesIndice 3 = "mar"
mesIndice 4 = "abr"
mesIndice 5 = "mai"
mesIndice 6 = "jun"
mesIndice 7 = "jul"
mesIndice 8 = "ago"
mesIndice 9 = "set"
mesIndice 10 = "out"
mesIndice 11 = "nov"
mesIndice 12 = "dez"

dataToString :: (Int, Int, Int) -> String
dataToString (ano, mes, dia) = (show dia) ++ "/" ++ (mesIndice mes) ++ "/" ++ (show ano)

horaToString :: Int -> String
horaToString hora = (show hora) ++ ":" ++ "00"

{-*********************************** Funes de manipulao de strings *********************************-}

-- Separa uma string em palavras
separaEmPalavras :: String -> [String]
separaEmPalavras [] = []
separaEmPalavras str = retiraPalavrasEmBranco((myGetWord (dropWhile (e_separador) str)) : (separaEmPalavras (myDropWord (dropWhile (e_separador) str))))

-- Obtm a primeira palavra da string		 
myGetWord :: String -> String
myGetWord [] = []
myGetWord (a:as) | (e_separador a) = []
		 | otherwise = a : myGetWord as
		 
-- Tira a primeira palavra da string		 
myDropWord :: String -> String
myDropWord [] = []
myDropWord (a:as) | (e_separador a) = (a:as)
		  | otherwise = myDropWord as

-- Tira os separadores do comeo da palavra		  
dropSeparator :: String -> String
dropSeparator [] = []
dropSeparator (a:as) | e_separador a = dropSeparator as
		     | otherwise = (a:as)
		     
retiraPalavrasEmBranco :: [String] -> [String]
retiraPalavrasEmBranco [] = []
retiraPalavrasEmBranco (a:as) | a == "" = retiraPalavrasEmBranco as
			      | otherwise = a : (retiraPalavrasEmBranco as) 		     		  
	  
e_separador :: Char -> Bool
e_separador ch = ch == ' ' || ch == '(' || ch == ')' || ch == ',' || ch == '.' 
		   || ch == ':' || ch == ';' || ch == '!' || ch == '?' || ch == '-'
		   || ch == '_' 	  


-- Coloca zero antes de um nmero com 1 algarismo				
formataNumero :: Int -> String 
formataNumero x | x < 10 =  "0" ++ (show x)
		| otherwise = (show x)


		
		
		


		   
-- Converte uma Maybe String em String		  
aux :: (Maybe String) -> String
aux Nothing = ""
aux (Just str) = str		

{-*****************************************************************************************************-}							   